@@ -41,6 +41,14 @@ def run(
 ):
     """
     Execute a GOR query via the Query API.
+
+    You can either run a query directly or from a file.
+
+    This command will automatically wait for the query
+    to complete and fetch results but if you are running a long
+    query you can use the --nowait option and then fetch results
+    via the results command.
+
     """
     svc = ctx.obj.service
 
@@ -109,7 +117,11 @@ def run(
 @click.pass_context
 def project(ctx, project):
     """
-    Set the current project
+    Set the current project.
+
+    This command will set the project context in the client and save it
+    into the current profile. A project is required to run any gor query
+    or to inspect already run queries.
     """
     svc = ctx.obj.service
     svc.client.profile.project = project
@@ -125,7 +137,7 @@ def project(ctx, project):
 @check_project
 def info(ctx, query_id, is_raw):
     """
-    Retrieve information about a gor query
+    Retrieve information about a gor query by ID
     """
     svc = ctx.obj.service
     qry = svc.get_query(query_id)
@@ -138,6 +150,7 @@ def info(ctx, query_id, is_raw):
     print_tab("Submitted", data['submit_date'])
     print_tab("User", data['user_name'])
     print_tab("Available", data['available'])
+    print_tab("Template", data['template_name'] or "None (ad-hoc)")
     status = data['status']
     col = 'red'
     if status == 'DONE':
@@ -246,7 +259,7 @@ def progress(ctx, query_id, is_raw):
 @click.command("list")
 @click.option('-u', '--user', 'user_name', help='User to filter for')
 @click.option('-s', '--status', 'status', default=None, help='Filter status')
-@click.option('-n', '--num', default=20, help='Maximum number of queries to return')
+@click.option('-n', '--num', default=20, help='Maximum number of queries to return', show_default=True)
 @click.option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
 @click.pass_context
 @check_project
